@@ -26,6 +26,7 @@ call_fns <- c(
   "$", "[[",
   "across.", "between",
   "c_across.", "case_when",
+  "cur_data.", "cur_data",
   "cur_group_rows.", "cur_group_rows", "cur_group_id.", "cur_group_id",
   "desc.", "desc",
   "glue",
@@ -41,12 +42,14 @@ prep_expr_call <- function(x, data, .by = NULL, j = FALSE, dt_env, is_top_across
     quote(.N)
   } else if (is_call(x, c("desc.", "desc"))) {
     x[[1]] <- sym("-")
-    x[[2]] <- get_expr(x[[2]])
+    x[[2]] <- prep_expr(x[[2]], data, {{ .by }}, j, dt_env, is_top_across)
     x
   } else if (is_call(x, c("row_number.", "row_number", "cur_group_rows.", "cur_group_rows"))) {
     quote(1:.N)
   } else if (is_call(x, c("cur_group_id.", "cur_group_id"))) {
     quote(.GRP)
+  } else if (is_call(x, c("cur_data.", "cur_data"))) {
+    quote(.SD)
   } else if (is_call(x, c("ifelse", "if_else"))) {
     if (is_call(x, "if_else")) {
       x <- call_match(x, internal_if_else)
@@ -81,7 +84,7 @@ prep_expr_call <- function(x, data, .by = NULL, j = FALSE, dt_env, is_top_across
     call <- call_match(x, tidytable::across., dots_expand = FALSE)
     .cols <- get_across_cols(data, call$.cols, {{ .by }})
     dots <- call$...
-    call_list <- across_calls(call$.fns, .cols, call$.names, dots)
+    call_list <- expand_across(call$.fns, .cols, call$.names, dots)
     out <- lapply(call_list, prep_expr, data, {{ .by }})
     if (!is_top_across) {
       out <- call2("data_frame", !!!out, .ns = "vctrs")
