@@ -1,19 +1,19 @@
 test_df <- data.table(
-  "col1"= letters[1:3],
-  "col2" = as.factor(letters[3:1]),
+  "col1"= c(letters[1:3], letters[1:3]),
+  "col2" = as.factor(c(letters[3:1], letters[3:1])),
   "var1"= rnorm(6,0,1))
 
 test_df2 <- data.table(
-  "col1"= c(letters[1:3], NA),
-  "col2" = as.factor(c(letters[3:1], NA)),
+  "col1"= c(letters[1:3], NA, letters[1:3]),
+  "col2" = as.factor(c(letters[3:1], NA, letters[3:1])),
   "var1"= rnorm(7,0,1))
 
-test_that("cols = NULL uses all cols - no NAs", {
+test_that("default uses all cols - no NAs", {
   dummy_df <- get_dummies.(test_df)
 
   expect_named(dummy_df, c("col1", "col2", "var1",
                            "col1_a", "col1_b", "col1_c",
-                           "col2_c", "col2_b", "col2_a"))
+                           "col2_a", "col2_b", "col2_c"))
 
   expect_equal(dummy_df$col1_a, c(1, 0, 0, 1, 0, 0))
   expect_equal(dummy_df$col1_b, c(0, 1, 0, 0, 1, 0))
@@ -31,7 +31,7 @@ test_that("works with data.frame input", {
 
   expect_named(dummy_df, c("col1", "col2", "var1",
                            "col1_a", "col1_b", "col1_c",
-                           "col2_c", "col2_b", "col2_a"))
+                           "col2_a", "col2_b", "col2_c"))
 
   expect_equal(dummy_df$col1_a, c(1, 0, 0, 1, 0, 0))
   expect_equal(dummy_df$col1_b, c(0, 1, 0, 0, 1, 0))
@@ -47,8 +47,8 @@ test_that("default uses all cols - with NAs", {
   dummy_df <- get_dummies.(test_df2)
 
   expect_named(dummy_df, c("col1", "col2", "var1",
-                           "col1_a", "col1_b", "col1_c", "col1_NA",
-                           "col2_c", "col2_b", "col2_a", "col2_NA"))
+                           "col1_NA","col1_a", "col1_b", "col1_c",
+                           "col2_NA", "col2_a", "col2_b", "col2_c"))
 
   expect_equal(dummy_df$col1_a, c(1, 0, 0, 0, 1, 0, 0))
   expect_equal(dummy_df$col1_b, c(0, 1, 0, 0, 0, 1, 0))
@@ -77,7 +77,7 @@ test_that("prefix_sep works", {
 
   expect_named(dummy_df, c("col1", "col2", "var1",
                            "col1.a", "col1.b", "col1.c",
-                           "col2.c", "col2.b", "col2.a"))
+                           "col2.a", "col2.b", "col2.c"))
 
   expect_equal(dummy_df$col1.a, c(1, 0, 0, 1, 0, 0))
   expect_equal(dummy_df$col1.b, c(0, 1, 0, 0, 1, 0))
@@ -94,7 +94,7 @@ test_that("drop_first works", {
 
   expect_named(dummy_df, c("col1", "col2", "var1",
                            "col1_b", "col1_c",
-                           "col2_b", "col2_a"))
+                           "col2_a", "col2_b"))
 
   expect_equal(dummy_df$col1_b, c(0, 1, 0, 0, 1, 0))
   expect_equal(dummy_df$col1_c, c(0, 0, 1, 0, 0, 1))
@@ -108,7 +108,7 @@ test_that("dummify_na = FALSE works", {
 
   expect_named(dummy_df, c("col1", "col2", "var1",
                            "col1_a", "col1_b", "col1_c",
-                           "col2_c", "col2_b", "col2_a"))
+                           "col2_a", "col2_b", "col2_c"))
 
   expect_equal(dummy_df$col1_a, c(1, 0, 0, 0, 1, 0, 0))
   expect_equal(dummy_df$col1_b, c(0, 1, 0, 0, 0, 1, 0))
