@@ -9,7 +9,7 @@ test_that("can construct a tidytable", {
 
 test_that("can construct using quosures", {
   create_dt <- function(name, val) {
-    tidytable({{name}} := val)
+    tidytable({{ name }} := val)
   }
 
   df <- create_dt(stuff, 1:3)
@@ -24,3 +24,10 @@ test_that("can create an empty tidytable", {
   expect_equal(names(df), character(0))
   expect_equal(nrow(df), 0)
 })
+
+test_that("can splice quosures", {
+  vals <- quos(x = 1, y = 2)
+  df <- tidytable(!!!vals)
+
+  expect_equal(df, tidytable(x = 1, y = 2))
+})
